@@ -1,4 +1,4 @@
-`ADM3` <- function(file, outfile, t=6, np=3, mr=0.3, fact=3) {		
+`ADM3` <- function(file, outfile, t=6, np=3, mr=0.3, autoCut=F) {		
 	rep=NULL; rr=NULL; data=read.table(file); u=unique(data[,1]);
 	for(y in 1:length(u)) {
 		print(y); d=data[data[,1]==u[y],]; re=NULL;		  
@@ -8,7 +8,7 @@
 							,"prob" = as.double(d[,5])
 		 					,"threshold" = as.double(t)
 		 					,"size" = as.integer(length(d[,4]))
-		 					,"PACKAGE" = "ADM3")$dat*(dLRs(d[,4])*fact)
+		 					,"PACKAGE" = "ADM3")$dat
 		 					)
 			,"st"= as.double(rep(0,length(d[,1])))
 			, "so"= as.double(rep(0,length(d[,1])))
@@ -23,7 +23,11 @@
 						re = rbind(re, cbind(d[ind[1],1],  d[ind[1],2],  d[ind[2],3], mean(d[ind[1]:ind[2],4]), mean(r[ind[1]:ind[2]]), (ind[2]-ind[1])+1, ind[1], ind[2]))
 					}
 				};	
-				rep=rbind(rep, re[abs(re[,4])>getCut(dLRs(d[,4]),mr) & re[,6]>np,]);
+				if(autoCut) {
+					rep = rbind(rep, re[abs(re[, 4]) > getCut(dLRs(d[,4]), mr) & abs(re[,5])>t & re[,6] > np, ]);
+           		} else {
+           			rep = rbind(rep, re[abs(re[,4])>0.3 & abs(re[,5])>t & re[,6]>3,]);
+           		}
 			}; rr=c(rr,res$d)
 	}
 	l=list(); l$data=cbind(data,rr); l$report=rep;
